==> estateplat-common-1.1.0-20160902.030133-173-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzGjzwsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 构（建）筑物所有权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:21
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_gjzwsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzGjzwsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //坐落
    @XmlElement(name = "zl")
    private String zl;
    //土地/海域使用权人
    @XmlElement(name = "tdhysyqr")
    private String tdhysyqr;
    //土地/海域使用面积
    @XmlElement(name = "tdhysymj")
    private Double tdhysymj;
    //土地/海域使用起始时间
    @XmlElement(name = "tdhysyqssj")
    private Date tdhysyqssj;
    //土地/海域使用结束时间
    @XmlElement(name = "tdhysyjssj")
    private Date tdhysyjssj;
    //构（建）筑物类型
    @XmlElement(name = "gjzwlx")
    private String gjzwlx;
    //构（建）筑物规划用途
    @XmlElement(name = "gjzwghyt")
    private String gjzwghyt;
    //构(建)筑物面积
    @XmlElement(name = "gjzwmj")
    private Double gjzwmj;
    //竣工时间
    @XmlElement(name = "jgsj")
    private Date jgsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getTdhysyqr() {
        return tdhysyqr;
    }

    public void setTdhysyqr(String tdhysyqr) {
        this.tdhysyqr = tdhysyqr;
    }

    public Double getTdhysymj() {
        return tdhysymj;
    }

    public void setTdhysymj(Double tdhysymj) {
        this.tdhysymj = tdhysymj;
    }

    public Date getTdhysyqssj() {
        return tdhysyqssj;
    }

    public void setTdhysyqssj(Date tdhysyqssj) {
        this.tdhysyqssj = tdhysyqssj;
    }

    public Date getTdhysyjssj() {
        return tdhysyjssj;
    }

    public void setTdhysyjssj(Date tdhysyjssj) {
        this.tdhysyjssj = tdhysyjssj;
    }

    public String getGjzwlx() {
        return gjzwlx;
    }

    public void setGjzwlx(String gjzwlx) {
        this.gjzwlx = gjzwlx;
    }

    public String getGjzwghyt() {
        return gjzwghyt;
    }

    public void setGjzwghyt(String gjzwghyt) {
        this.gjzwghyt = gjzwghyt;
    }

    public Double getGjzwmj() {
        return gjzwmj;
    }

    public void setGjzwmj(Double gjzwmj) {
        this.gjzwmj = gjzwmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20220607.092754-1035-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzGjzwsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 构（建）筑物所有权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:21
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_gjzwsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzGjzwsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //坐落
    @XmlElement(name = "zl")
    private String zl;
    //土地/海域使用权人
    @XmlElement(name = "tdhysyqr")
    private String tdhysyqr;
    //土地/海域使用面积
    @XmlElement(name = "tdhysymj")
    private Double tdhysymj;
    //土地/海域使用起始时间
    @XmlElement(name = "tdhysyqssj")
    private Date tdhysyqssj;
    //土地/海域使用结束时间
    @XmlElement(name = "tdhysyjssj")
    private Date tdhysyjssj;
    //构（建）筑物类型
    @XmlElement(name = "gjzwlx")
    private String gjzwlx;
    //构（建）筑物规划用途
    @XmlElement(name = "gjzwghyt")
    private String gjzwghyt;
    //构(建)筑物面积
    @XmlElement(name = "gjzwmj")
    private Double gjzwmj;
    //竣工时间
    @XmlElement(name = "jgsj")
    private Date jgsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getTdhysyqr() {
        return tdhysyqr;
    }

    public void setTdhysyqr(String tdhysyqr) {
        this.tdhysyqr = tdhysyqr;
    }

    public Double getTdhysymj() {
        return tdhysymj;
    }

    public void setTdhysymj(Double tdhysymj) {
        this.tdhysymj = tdhysymj;
    }

    public Date getTdhysyqssj() {
        return tdhysyqssj;
    }

    public void setTdhysyqssj(Date tdhysyqssj) {
        this.tdhysyqssj = tdhysyqssj;
    }

    public Date getTdhysyjssj() {
        return tdhysyjssj;
    }

    public void setTdhysyjssj(Date tdhysyjssj) {
        this.tdhysyjssj = tdhysyjssj;
    }

    public String getGjzwlx() {
        return gjzwlx;
    }

    public void setGjzwlx(String gjzwlx) {
        this.gjzwlx = gjzwlx;
    }

    public String getGjzwghyt() {
        return gjzwghyt;
    }

    public void setGjzwghyt(String gjzwghyt) {
        this.gjzwghyt = gjzwghyt;
    }

    public Double getGjzwmj() {
        return gjzwmj;
    }

    public void setGjzwmj(Double gjzwmj) {
        this.gjzwmj = gjzwmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
